<?PHP

define('ADFC_API_SERVER', 'https://www.adfc-tour.de/');

/** Hole Daten von ADFC-Tour.de via RSSX
 * @param string $organisation Name der ADFC-Organisation
 * @param string $parameter    Anfrageparameter
 * @param int $cachezeit       Wie lange soll gechached werden (in sec)
 * @param string server        ADFC-Tour-Server
 * @param string schluessel    Schlüssel der Organisation
 * @return array
 */
function hole_rss_data4 (string $organisation,
		string $parameter, int $cachezeit=3600,
        string $server=ADFC_API_SERVER, string $schluessel="" ): array {

  // verwende eine Cache-Datei aus dem lokalen temporären Verzeichnis, 
  // wenn diese nicht älter als 3600 sec ist.
  $cachedir=sys_get_temp_dir() . "/rss_cache_".$organisation;
  if (! is_dir($cachedir)) {
    mkdir($cachedir);
  }
  $cachefile="$cachedir/". md5(strtr($parameter.$schluessel,"/\:?& ", "______"));
  //echo $cachefile;
  
  $dom = new DOMDocument();
  $usecache=0;
  if (file_exists($cachefile)
      &&  ((time()-filemtime($cachefile)) < $cachezeit)) {
    //echo "<p> verwende Cache-Datei $cachefile, die ". (time()-filemtime($cachefile)) ." s alt ist </p>\n";
    $usecache=1;
    $dom->load($cachefile);
  } else {
      $parameter='ausgabe=rssx&'.$parameter;      
      
      $curl_session = curl_init();
      curl_setopt($curl_session, CURLOPT_USERAGENT, 
      		"$organisation Tourenprogramm V4");
      #echo "URL:".$server.'touren.php?'.$parameter;
      curl_setopt($curl_session, CURLOPT_URL, $server.'touren.php?'.$parameter);
      curl_setopt($curl_session, CURLOPT_RETURNTRANSFER, true);
      if ($schluessel != "") {
        # sende geheimen Schlüssel im HTTP-Kopf, dann erscheint er nicht im Log
        curl_setopt($curl_session, CURLOPT_HTTPHEADER, 
         		array('Privatschluessel: '.$schluessel));
      }
      $string= curl_exec($curl_session );
      $httpCode = curl_getinfo($curl_session, CURLINFO_HTTP_CODE); 
      #echo "httpCode: $httpCode, $string <br/>";
      if($httpCode == 404) {
      	return array();
      }
      #echo "XML:".$string."END";
      $dom->loadXML($string);
      curl_close($curl_session );      
  }
  
  $output=array();
  
  if ($dom->documentElement->nodeName == "rss") {
  	# RSS
	$xpath = new DOMXpath($dom);
	$queryResult =$xpath->query("//item");
	foreach($queryResult as $item) {
	  $tour=array();
	  $tour["id"]=$item->getAttribute("id");
	  //$tour["titel"]=$item->getElementsByTagName("title")->item(0)->nodeValue;
	  foreach($item->childNodes as $child) {
	    if(($child->nodeName == "#text")) {
			//nix
      	} elseif ($child->hasAttributes()) {
          foreach ($child->attributes as $attr) {
            $name = $attr->nodeName;
            $value = $attr->nodeValue;
            $tour[$child->nodeName .'+'.$name]=$value;
          }
          $tour[$child->nodeName]=$child->nodeValue;	
      	} else {
          $tour[$child->nodeName]=$child->nodeValue;
      	}	
      }
      // Leiter
      $queryResultLeiter =$xpath->query(".//details-leiter/details-person", $item);
      $leiterListe=array();
      foreach($queryResultLeiter as $leiterEl) {
          $leiterDetails=array();
          $leiterDetails["name"]=$leiterEl->nodeValue;
          $leiterDetails["person_id"]=$leiterEl->getAttribute("person_id");

          if($leiterEl->hasAttribute("email")) {
              $leiterDetails["email"]=$leiterEl->getAttribute("email");
          }
          if($leiterEl->hasAttribute("privtel")) {
              $leiterDetails["privtel"]=$leiterEl->getAttribute("privtel");
          }
          if($leiterEl->hasAttribute("mobtel")) {
              $leiterDetails["mobtel"]=$leiterEl->getAttribute("mobtel");
          }
          $leiterListe[]=$leiterDetails;
      }
    $tour["leiter"]=$leiterListe;

    $output[]=$tour;
  	}
  } elseif ($dom->documentElement->nodeName == "data") {
  	# einfache Liste
  	foreach ($dom->getElementsByTagName('item') as $itemEl) {
  		$item=array();
  		$item["text"]=$itemEl->textContent;
  		foreach ($itemEl->attributes as $attr) {
  			$name = $attr->nodeName;
  			$value = $attr->nodeValue;
  			$item[$name]=$value;
  		}  		
  		$output[]=$item;
  	}
  } else {
      error_log("Server-Antwort kann nicht verarbeitet werden: unbekanntes Format. Query: ". $server.'touren.php?'.$parameter);
      die("Server-Antwort kann nicht verarbeitet werden: unbekanntes Format ".$dom->documentElement->nodeName. $string);
  }
  if (!$usecache) {
    $dom->save($cachefile,0);
  }
  return $output;
}


/** leere lokalen Zwischenspeicher
 * @param string $organisation Name der Organisation, wie bei hole_rss_data3 angegeben
 */
function leere_speicher(string $organisation): void {
  $cachedir=sys_get_temp_dir() . "/rss_cache_".$organisation;
  $files = glob("$cachedir/*");
  foreach($files as $file){
    if(is_file($file))
      unlink($file);
  }
}



?>
